<html>
<head>
    <title>Website created successfully - Hosted by bigsansar.com</title>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <style type="text/css">
    .clear {display:inline-block;}
    .clear:after {content:" ";display:block;height:0;clear:both;overflow:hidden;visibility:hidden;}
    .clear {display:block;}
    body {background-color:#f9f9f9;font-family:Tahoma,Geneva,Kalimati,sans-serif;}
    img {border:none;}
    #content {width:963px; margin-left:auto;margin-right:auto;margin-top:90px;}
    #logo {top:36px;left:55px;position:absolute;display:block;width:auto;height:auto;}
    #content .content {background: #6b6b6b  repeat-y 7px top; margin:0;position:relative;float:left;width:961px;background-size:99%;height:300px;}
    h1 {font-size:40px;text-align:center;font-weight:700;color:white;margin-top:130px;}
    #content p {color:#ffffff;font-size:15px;padding:0 69px;}
    #footer {clear:both;font-size:11px;color:#999999;width:961px;margin-left:auto;margin-right:auto;margin-top:25px;margin-bottom:20px;position:relative;}
    #footer .links a {color:#999999;}
    #footer .links {text-align:center;}
    #footer .links .pipe {color:#cccccc;}
    #footer .copyright {color:#6b6b6b;text-align:center;margin-top:6px;}
	</style>
</head>
<body>
<div id="main">
    <div id="content">
        <div class="content">
            <h1>Your Page has been created!</h1>
            <p>Your Page has been successfully installed on the server! Please Edit the file <b>{{ path }}</b> from the <b>pages</b> </p>
            <div class="bottom"></div>
            <div class="clear"></div></div>
        <div class="clear"></div></div>
    <div class="clear"></div></div>
<div id="footer">
    <div class="links">
        <a href="https://bigsansar.com" target="_blank">Free Hosting</a>
        <span class="pipe">|</span>
        <a href="https://bigsansar.com/login" target="_blank">Login</a>
        <span class="pipe">|</span>
        <a href="http://www.facebook.com/bigsansar" target="_blank">Find on Facebook</a>
    </div>
    <div class="copyright">Copyright &copy; Bigsansar.com <?php echo date(Y);?>. All rights reserved</div>
</div>
</div>
</body>
</html>