CKEDITOR.plugins.setLang('youtube', 'bg', {
	button : 'Вмъкни YouTube видео',
	title : 'Вграждане на YouTube видео',
	txtEmbed : 'Въведете кода за вграждане тук',
	txtUrl : 'Въведете YouTube видео URL',
	txtWidth : 'Ширина',
	txtHeight : 'Височина',
	chkRelated : 'Показва предложени видеоклипове в края на клипа',
	txtStartAt : 'Стартирай в (ss или mm:ss или hh:mm:ss)',
	chkPrivacy : 'Активирай режим за поверителност',
	chkOlderCode : 'Използвай стар код за вграждане',
	chkAutoplay: 'Авто стартиране',
	chkControls: 'Показва контролите на плейъра',
	noCode : 'Трябва да въведете код за вграждане или URL адрес',
	invalidEmbed : 'Кодът за вграждане, който сте въвели, не изглежда валиден',
	invalidUrl : 'Въведеният URL адрес не изглежда валиден',
	or : 'или',
	noWidth : 'Трябва да заложите ширината',
	invalidWidth : 'Заложете валидна ширина',
	noHeight : 'Трябва да заложите височина',
	invalidHeight : 'Заложете валидна височина',
	invalidTime : 'Заложете валидно време за стартиране',
	txtResponsive : 'Напасва по ширина (игнорира Ширина и Височина)',
	txtNoEmbed : 'Само видео изображение и връзка'
});
